@@ -14,7 +14,7 @@ _logger = getLogger(__name__)
 
 
 class Paths:
-    def __init__(self, working_dir: str) -> None:
+    def __init__(self, working_dir: str, check_depth: bool = True) -> None:
         self.working_dir = Path(working_dir).resolve()
         self.build_dir = self.working_dir / "build"
         self.pdf_dir = self.working_dir / "pdf"
@@ -26,6 +26,8 @@ class Paths:
         self.template_latex = self.templates_dir / "subsection.tex"
         self.template_targets = self.templates_dir / "targets.yml"
         self.jinja2_dir = self.git_dir / "jinja2"
+        self.jinja2_main_template = self.jinja2_dir / "main.tex.jinja2"
+        self.jinja2_print_template = self.jinja2_dir / "print.tex.jinja2"
         self.user_config_dir = Path(user_config_dir(app_name))
         self.global_config = self.git_dir / "global-config.yml"
         self.user_config = self.user_config_dir / "user-config.yml"
@@ -36,7 +38,7 @@ class Paths:
 
         self.user_config_dir.mkdir(parents=True, exist_ok=True)
 
-        if not self.working_dir.relative_to(self.git_dir).match("*/*"):
+        if check_depth and not self.working_dir.relative_to(self.git_dir).match("*/*"):
             raise DeckzException(
                 f"Not deep enough from root {self.git_dir}. "
                 "Please follow the directory hierarchy root > company > deck and "
@@ -55,6 +57,3 @@ class Paths:
                 ) from e
             self._git_dir = Path(repository.git.rev_parse("--show-toplevel")).resolve()
         return self._git_dir
-
-    def get_jinja2_template_path(self, version: str) -> Path:
-        return self.jinja2_dir / f"{version}.tex.jinja2"
